import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * A card stack - cards are placed on this of the same suit, from
 * Ace to King. The game is over when all 4 stacks are completed.
 * 
 * @author Michael Berry
 * @version 23/04/09
 */
public class CardStack extends Actor implements Accepter
{
    /** The card on top of the stack. */
    private Card lastCard;

    /**
     * Initially set the image to an empty stack.
     */
    public void addedToWorld(World world) {
        setImage("images/cards/empty.png");
    }
    
    /**
     * Determine whether the stack is full (complete.)
     * @return true if the stack is complete, false otherwise.
     */
    public boolean isComplete() {
        if(lastCard==null) return false;
        return lastCard.getValue()==Card.Value.KING;
    }
    
    /**
     * Add a card onto the stack if it's legal.
     * @return true if the card has been added, false if it's been rejected.
     */
    public boolean addCard(Card card) {
        if(lastCard==null && card.getValue()==Card.Value.ACE) {
            add(card);
            return true;
        }
        if(lastCard==null) return false;
        if(card.getSuit()==lastCard.getSuit() && lastCard.getValue().ordinal()+1==card.getValue().ordinal()) {
            add(card);
            return true;
        }
        return false;
    }
    
    /**
     * Add a card to the stack of cards.
     */
    private void add(Card card) {
        if(card.getAccepter()!=null) {
            ((Pile)(card.getAccepter())).remove();
            card.setAccepter(this);
        }
        card.setAccepter(this);
        lastCard = card;
        card.setLocation(getX(), getY());
        card.setDraggable(false);
    }
}
