import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.List;
import java.util.Stack;
import java.util.ArrayList;
import java.util.HashSet;

/**
 * A table to put cards on.
 * 
 * @author Michael Berry
 * @version 23/04/09
 */
public class Table extends World
{

    private Deck deck;
    private Card showCard;
    private HashSet<CardStack> stacks;

    /**
     * Create a new table
     */
    public Table()
    {    
        super(600, 400, 1);
        Greenfoot.setSpeed(50);
        
        stacks = new HashSet<CardStack>();
        deck = new Deck(Card.Colour.BLUE, false, 1, 1, 1, 1);
        deck.fill();
        deck.shuffle();
        addObject(deck, 40, 50);
        
        for(int i=0 ; i<4 ; i++) {
            CardStack stack = new CardStack();
            stacks.add(stack);
            addObject(stack, 230+i*100, 50);
        }
        
        List<Pile> piles = new ArrayList<Pile>();
        
        ArrayList<Stack<Card>> cards = new ArrayList<Stack<Card>>();
        
        for(int max=0; max<7 ; max++) {
            cards.add(new Stack<Card>());
            for(int i=0 ; i<max+1 ; i++) {
                Card card = deck.drawCard();
                cards.get(cards.size()-1).push(card);
            }
        }
        
        for(int i=0 ; i<7 ; i++) {
            Pile pile = new Pile(cards.get(i));
            piles.add(pile);
            addObject(pile, 40+i*80, 270);
        }
        
        Greenfoot.start();        
    }
    
    /**
     * If the deck is clicked on, cycle through the cards.
     */
    public void act()
    {
        boolean won = true;
        for(CardStack stack : stacks) {
            if(! stack.isComplete()) won = false;
        }
        if(won) {
            BigText text = new BigText();
            addObject(text, 200, 300);
            text.setText("Game complete!");
            Greenfoot.stop();
        }
        
        if(Greenfoot.mouseClicked(deck) && deck.getSize()>0) {
            if(showCard != null && showCard.getAccepter()==null) {
                removeObject(showCard);
                deck.addCard(showCard);
            }
            showCard = deck.drawCard();
            Greenfoot.playSound("sounds/card.wav");
            addObject(showCard, 120, 50);
            showCard.setDraggable(true);
        }
    }
}
